#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-BflLqOVRUEVJbJio8jNhrd
key:                  lsp-2.2.0.0-BflLqOVRUEVJbJio8jNhrd
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  c53334961e49d0b75eb0295d55fc55a7
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-BflLqOVRUEVJbJio8jNhrd
depends:
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    async-2.2.6-HVFcnXCzrULJJSPrXugzlh
    attoparsec-0.14.4-5JdM0c7xj70IPbvJjnzZkg base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-JwQaGHgO52fKuBumEXpdoN
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p
    lens-5.3.4-FLE2Mpdc2NQ9IUFEHfSpBl
    lens-aeson-1.2.3-3wxm9ClSkk5QWE5nNXKgu
    lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI mtl-2.3.1
    prettyprinter-1.7.1-EN3LFPJyyjtK4N4FJxxajw
    random-1.2.1.3-DTsWC2j5NX8JAyBJGSl6m
    row-types-1.0.1.2-K3TJoJIddBpDd7HPcMPa9t
    sorted-list-0.2.3.1-8Kgmt1KD4WNolzYc99roV stm-2.5.1.0
    temporary-1.3-9Sgzyj9UgJk68u87dA2OiK text-2.0.2
    text-rope-0.3-5JZpdxmQjTaGQAecvZ7sRv transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    uuid-1.3.16.1-907nm4R9lNz4H1OdRyxaGu

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

